DarlightFourOption class

Inheritance

Constructors

DarlightFourOption({Color darkIconColor = Colors.white, Color lightIconColor = Colors.orange})

Properties

darkIconColor Color
final
hashCode int
The hash code for this object.
no setterinherited
lightIconColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited